@@ -2,11 +2,11 @@ import tensorflow
 import torch
 import keras
 from tensorflow.keras.callbacks import LambdaCallback
-import eval_measure
-from corpus import DocData,DocDatalstm
+import .eval_measure
+from .corpus import DocData,DocDatalstm
 import ldann
 from ldann import Doc2Topic,Logger,data_feeder,Doc2Topiclstm
-from eval_measure import custom_evaluator
+from .eval_measure import custom_evaluator
 import os
 import collections
 import numpy as np
